@@ -1,6 +1,7 @@
 from traitlets import Any, List
 
 from ..apps.assignment_list import AssignmentList
+from ..apps.diagram_editor import DiagramEditor
 from ..apps.help import Help
 from ..apps.validate_assignment import ValidateAssignment
 from ..base import BaseExtension
@@ -9,7 +10,7 @@ from ..base import BaseExtension
 class StudentExtension(BaseExtension):
     apps = List(
         trait=Any(),
-        default_value=[AssignmentList, ValidateAssignment, Help],
+        default_value=[AssignmentList, ValidateAssignment, Help, DiagramEditor],
     ).tag(config=True)
 
 
